package com.huimv.cattle.controller;


import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.DataSource;
import com.huimv.cattle.pojo.FarmStockRank;
import com.huimv.cattle.pojo.SalesCattle;
import com.huimv.cattle.pojo.SysFarm;
import com.huimv.cattle.pojo.vo.FarmStockRankVo;
import com.huimv.cattle.service.DataSourceService;
import com.huimv.cattle.service.FarmStockRankService;
import com.huimv.cattle.service.SysFarmService;
import com.huimv.cattle.utils.FarmCodeUtils;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@CrossOrigin
@RestController
@RequestMapping("/v1.0.0/farmStockRank")
public class FarmStockRankController {

    @Autowired
    private FarmStockRankService farmStockRankService;
    @Resource
    private DataSourceService dataSourceService;
    @Resource
    private RestTemplate restTemplate;
    @Autowired
    private SysFarmService farmService;

    @PostMapping("/saveFarmStockRank")
    @Transactional
    public Result add(@RequestBody FarmStockRankVo farmStockRankVo, HttpServletRequest request){
        String farmCode = FarmCodeUtils.getFarmCode(farmStockRankVo.getFarmCode(), request);
        List<FarmStockRank> farmStockRanks = farmStockRankVo.getFarmStockRanks();
        farmStockRankService.remove(new QueryWrapper<FarmStockRank>().eq("farm_code",farmCode));
        for (FarmStockRank farmStockRank : farmStockRanks) {
            farmStockRank.setFarmCode(farmCode);
            farmStockRankService.save(farmStockRank);
        }
        return new Result(10000,"添加成功",true);
    }
    @PostMapping("/updateFarmStockRank")
    public  Result update(@RequestBody FarmStockRank farmStockRank){
        farmStockRankService.updateById(farmStockRank);
        return new Result(10000,"修改成功",true);
    }
    @PostMapping("/deleteFarmStockRank")
    public  Result delete(@RequestBody Map<String,String> paramMap){
        String ids = paramMap.get("ids");
        String[] split = ids.split(",");
        for (String s : split) {
            farmStockRankService.removeById(s);
        }
        return new Result(10000,"删除成功",true);
    }
    @PostMapping("/getFarmStockRank")
    public  Result list(@RequestBody FarmStockRank farmStockRank,HttpServletRequest request){
        String farmCode = FarmCodeUtils.getFarmCode(farmStockRank.getFarmCode(), request);
        //        //读取模式切换
        DataSource dataSource = dataSourceService.getDataSourceStatus();
        if (dataSource.getViewType() == 1) {
            //view=1,显示县填写数据
            return  farmStockRankService.getFarmStockRank(farmCode);
        } else {
            //view=2,显示镇汇总数据
            if (dataSource.getDsStatus() == 1) {
                //status=1,显示镇汇总（手填）数据
                return  farmStockRankService.getFarmStockRank(farmCode);
            } else {
                //status=2,显示镇汇总（养殖云）数据
                System.out.println("status=2,显示镇汇总（养殖云）数据");
                String farmCodes =  getFarmCodeByAdcode(farmCode);
                if (StringUtils.isBlank(farmCodes) ){
                    return new Result(ResultCode.SUCCESS,new ArrayList<>());
                }
                return getStockRankByDivision(farmCodes);
            }
        }
    }

    private Result getStockRankByDivision(String farmCodes) {
        System.out.println("1");
        HttpHeaders httpHeaders = new HttpHeaders();
        MediaType type = MediaType.parseMediaType("application/json;charset=UTF-8");
        httpHeaders.setContentType(type);
        HashMap<String, String> map = new HashMap<>();
        //这里提交的是区县编码或乡镇编码
        map.put("farmCodes", farmCodes);
        HttpEntity<Map<String, String>> objectHttpEntity = new HttpEntity<>(map, httpHeaders);
        //读取真实数据
        String remoteUrl = "http://123.60.134.84:10001/breed/api/v1.0.0/cattle/getStockRankByDivision";
        ResponseEntity<String> entity = restTemplate.postForEntity(remoteUrl, objectHttpEntity, String.class);
        if(entity.getStatusCode().toString().contains("200")){
            String body = entity.getBody();
            System.out.println(body);
            JSONArray dataJo = JSON.parseObject(body).getJSONArray("data");
            System.out.println("dataJo="+dataJo);
            //, )
            return new Result(ResultCode.SUCCESS,dataJo);
        }else{
            return new Result(ResultCode.FAIL,"调取远程数据出错.");
        }
    }

    private String getFarmCodeByAdcode(String farmCode) {
        String adcode  = "620826";
        if (!"0".equals(farmCode)){
            SysFarm list = farmService.getOne(new QueryWrapper<SysFarm>().eq("farm_code", farmCode));
            if (ObjectUtil.isNotEmpty(list)){
                String[] split = list.getAdcode().split(",");
                adcode =  split[split.length-1];
            }
        }
        String remoteUrl = "http://123.60.134.84:10001/admin/v1.0.0/account/getFarmByAdcode";
        Map map = new HashMap();
        map.put("adcode",adcode);
        ResponseEntity<String> stringResponseEntity = restTemplate.postForEntity(remoteUrl, map, String.class);
//        JSONArray jsonObject = JSON.parseArray(stringResponseEntity.getBody());
//        System.out.println(jsonObject);
        return stringResponseEntity.getBody();
    }
}

