package com.huimv.cattle.controller;


import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.FarmStockRank;
import com.huimv.cattle.pojo.VaccineDelivery;
import com.huimv.cattle.pojo.vo.VaccineDeliveryVo;
import com.huimv.cattle.service.VaccineDeliveryService;
import com.huimv.cattle.utils.FarmCodeUtils;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@CrossOrigin
@RestController
@RequestMapping("/v1.0.0/vaccineDelivery")
public class VaccineDeliveryController {
    @Autowired
    private VaccineDeliveryService vaccineDeliveryService;

    @PostMapping("/saveVaccineDelivery")
    @Transactional
    public Result add(@RequestBody VaccineDeliveryVo vaccineDeliveryVo, HttpServletRequest request){
        String farmCode = FarmCodeUtils.getFarmCode(vaccineDeliveryVo.getFarmCode(), request);
        List<VaccineDelivery> vaccineDeliveries = vaccineDeliveryVo.getVaccineDeliveryList();
        vaccineDeliveryService.remove(new QueryWrapper<VaccineDelivery>().eq("farm_code",farmCode));
        System.out.println(farmCode);
        for (VaccineDelivery vaccineDelivery : vaccineDeliveries) {
            vaccineDelivery.setFarmCode(farmCode);
            vaccineDeliveryService.save(vaccineDelivery);
        }
        return new Result(10000,"添加成功",true);
    }
    @PostMapping("/updateVaccineDelivery")
    public  Result update(@RequestBody VaccineDelivery vaccineDelivery){
        vaccineDeliveryService.updateById(vaccineDelivery);
        return new Result(10000,"修改成功",true);
    }
    @PostMapping("/deleteVaccineDelivery")
    public  Result delete(@RequestBody Map<String,String> paramMap){
        String ids = paramMap.get("ids");
        String[] split = ids.split(",");
        for (String s : split) {
            vaccineDeliveryService.removeById(s);
        }
        return new Result(10000,"删除成功",true);
    }
    @PostMapping("/list")
    public  Result list(@RequestBody VaccineDelivery vaccineDelivery){
        List<VaccineDelivery> list = vaccineDeliveryService.list(new QueryWrapper<VaccineDelivery>().orderByDesc("year"));
        if (ObjectUtil.isEmpty(list)){
            return new Result(ResultCode.SUCCESS,new ArrayList<>());
        }
        return new Result(ResultCode.SUCCESS,list);
    }

    @PostMapping("/getVaccineDelivery")
    public  Result getVaccineDelivery(@RequestBody Map<String,String> paramMap, HttpServletRequest request){
        String yearNum = paramMap.get("yearNum");
        String farmCode = FarmCodeUtils.getFarmCode(paramMap.get("farmCode"), request);
        if (StringUtils.isBlank(yearNum)){
            yearNum ="0";
        }
        int year = DateUtil.year(new Date());
        List<VaccineDelivery> list = vaccineDeliveryService.list(new QueryWrapper<VaccineDelivery>().eq("farm_code",farmCode).ge("year", (year - Integer.parseInt(yearNum))));
        return new Result(ResultCode.SUCCESS,list);
    }
}

