package com.huimv.cattle.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.FarmKindCount;
import com.huimv.cattle.mapper.FarmKindCountMapper;
import com.huimv.cattle.pojo.IndustryOutput;
import com.huimv.cattle.pojo.ProductionCapacity;
import com.huimv.cattle.service.FarmKindCountService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class FarmKindCountServiceImpl extends ServiceImpl<FarmKindCountMapper, FarmKindCount> implements FarmKindCountService {
    @Autowired
    private FarmKindCountMapper farmKindCountMapper;

    @Override
    public Result getFarmKindCount(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)) {
            farmCode = TokenSign.getFarmCode(request);
        }
        List<FarmKindCount> farmKindCount = farmKindCountMapper.getFarmKindCount(farmCode);
        return new Result(ResultCode.SUCCESS, farmKindCount);
    }

    @Override
    public Result saveFarmKindCount(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)) {
            farmCode = TokenSign.getFarmCode(request);
        }
        String list = paramsMap.get("list");
        JSONArray listJa = JSONArray.parseArray(list);
        List<FarmKindCount> farmKindCountList = listJa.toJavaList(FarmKindCount.class);
        if (checkRepeat(farmKindCountList)) {
            return new Result(10001, "有重复类型", false);
        } else {
            farmKindCountMapper.deleteAll(farmCode);
        }
        for (int a = 0; a < listJa.size()  ; a++) {
            JSONObject jsonObject = listJa.getJSONObject(a);
            FarmKindCount farmKindCount = new FarmKindCount();
            farmKindCount.setFarmKind(jsonObject.getString("farmKind"));
            farmKindCount.setFarmCount(jsonObject.getInteger("farmCount"));
            farmKindCount.setFarmCode(farmCode);
            farmKindCountMapper.insert(farmKindCount);
        }
        return new Result(ResultCode.SUCCESS);
    }

    private Boolean checkRepeat(List<FarmKindCount> list) {
        List<String> collectionOptionList = new ArrayList<>();
        for (FarmKindCount a : list) {
            collectionOptionList.add(a.getFarmKind());
        }
        Set<String> set = new HashSet<>(collectionOptionList);
        return collectionOptionList.size() != set.size();
    }
}
