package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.DataSource;
import com.huimv.cattle.pojo.IndustryOutput;
import com.huimv.cattle.mapper.IndustryOutputMapper;
import com.huimv.cattle.pojo.OnlineService;
import com.huimv.cattle.pojo.SubsidyCount;
import com.huimv.cattle.service.DataSourceService;
import com.huimv.cattle.service.IndustryOutputService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.cattle.utils.DateUtil;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class IndustryOutputServiceImpl extends ServiceImpl<IndustryOutputMapper, IndustryOutput> implements IndustryOutputService {
    @Autowired
    private IndustryOutputMapper industryOutputMapper;
    @Resource
    private DataSourceService dataSourceService;
    @Autowired
    private DateUtil dateUtil;

    @Override
    public Result getIndustryOutput(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)) {
            farmCode = TokenSign.getFarmCode(request);
        }
        String yearNum = paramsMap.get("yearNum");
//        if (StringUtils.isBlank(yearNum)){
//            yearNum = "0";
//        }
        QueryWrapper<IndustryOutput> queryWrapper = new QueryWrapper<IndustryOutput>();
        if (StringUtils.isNotBlank(yearNum)) {
            queryWrapper.between("year", Integer.valueOf(dateUtil.getThisYear()) - Integer.valueOf(yearNum), Integer.valueOf(dateUtil.getThisYear()));
            //        queryWrapper.last("LIMIT "+yearNum);
        }
        queryWrapper.eq("farm_code", farmCode);
        queryWrapper.orderByDesc("year");

        List<IndustryOutput> industryOutputs = industryOutputMapper.selectList(queryWrapper);
        if (industryOutputs.isEmpty()) {
            IndustryOutput industryOutput = new IndustryOutput();
            industryOutput.setYear(dateUtil.getThisYear());
            industryOutput.setFarmCode(farmCode);
            industryOutputMapper.insert(industryOutput);
            industryOutputs.add(industryOutput);
        }
        return new Result(ResultCode.SUCCESS, industryOutputs);
    }

    @Override
    public Result saveIndustryOutput(HttpServletRequest request, Map<String, String> paramsMap) {

        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)) {
            farmCode = TokenSign.getFarmCode(request);
        }
        String list = paramsMap.get("list");
        JSONArray listJa = JSONArray.parseArray(list);
        List<IndustryOutput> industryOutputList = listJa.toJavaList(IndustryOutput.class);
        if (checkRepeat(industryOutputList)) {
            return new Result(10001, "有重复年份", false);
        } else {
            industryOutputMapper.deleteAll(farmCode);
        }
        for (int a = listJa.size() - 1; a >= 0; a--) {
            JSONObject jsonObject = listJa.getJSONObject(a);
            IndustryOutput industryOutput = new IndustryOutput();
            industryOutput.setYear(jsonObject.getString("year"));
            industryOutput.setSalesMoney(jsonObject.getBigDecimal("salesMoney"));
            industryOutput.setFarmCode(farmCode);
            industryOutputMapper.insert(industryOutput);
        }
        return new Result(ResultCode.SUCCESS);
    }

    @Override
    public Result getIndustryOutputScreen(HttpServletRequest request, Map<String, String> paramsMap) {
        DataSource dataSource = dataSourceService.getDataSourceStatus();
        if (dataSource.getDsStatus() == 1 && dataSource.getViewType() ==2) {
            List<IndustryOutput> industryOutputs =  industryOutputMapper.getIndustryOutputScreen();
            return new Result(ResultCode.SUCCESS,industryOutputs);
        }

        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)) {
            farmCode = TokenSign.getFarmCode(request);
        }
        String yearNum = paramsMap.get("yearNum");
//        if (StringUtils.isBlank(yearNum)){
//            yearNum = "0";
//        }
        QueryWrapper<IndustryOutput> queryWrapper = new QueryWrapper<IndustryOutput>();
        if (StringUtils.isNotBlank(yearNum)) {
            queryWrapper.between("year", Integer.valueOf(dateUtil.getThisYear()) - Integer.valueOf(yearNum), Integer.valueOf(dateUtil.getThisYear()));
            //        queryWrapper.last("LIMIT "+yearNum);
        }
        queryWrapper.eq("farm_code", farmCode);
        queryWrapper.orderByDesc("year");

        List<IndustryOutput> industryOutputs = industryOutputMapper.selectList(queryWrapper);
        if (industryOutputs.isEmpty()) {
            IndustryOutput industryOutput = new IndustryOutput();
            industryOutput.setYear(dateUtil.getThisYear());
            industryOutput.setFarmCode(farmCode);
            industryOutputMapper.insert(industryOutput);
            industryOutputs.add(industryOutput);
        }
        return new Result(ResultCode.SUCCESS, industryOutputs);
    }

    private Boolean checkRepeat(List<IndustryOutput> list) {
        List<String> collectionOptionList = new ArrayList<>();
        for (IndustryOutput a : list) {
            collectionOptionList.add(a.getYear());
        }
        Set<String> set = new HashSet<>(collectionOptionList);
        return collectionOptionList.size() != set.size();
    }
}
