package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.huimv.cattle.pojo.DataSource;
import com.huimv.cattle.pojo.OnlineService;
import com.huimv.cattle.mapper.OnlineServiceMapper;
import com.huimv.cattle.service.DataSourceService;
import com.huimv.cattle.service.OnlineServiceService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class OnlineServiceServiceImpl extends ServiceImpl<OnlineServiceMapper, OnlineService> implements OnlineServiceService {
    @Autowired
    private OnlineServiceMapper onlineServiceMapper;
    @Resource
    private DataSourceService dataSourceService;
    @Override
    public Result getOnlineServiceScreen(HttpServletRequest request, Map<String, String> paramsMap) {
        DataSource dataSource = dataSourceService.getDataSourceStatus();
        if (dataSource.getDsStatus() == 1 && dataSource.getViewType() ==2) {
           OnlineService   onlineService =  onlineServiceMapper.getOnlineServiceScreen();
            return new Result(ResultCode.SUCCESS,onlineService);
        }
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)){
            farmCode = TokenSign.getFarmCode(request);
        }
        OnlineService onlineService = onlineServiceMapper.getOnlineService(farmCode);
        if (ObjectUtil.isEmpty(onlineService)){
            onlineService = new OnlineService();
            onlineService.setTreatCount(0);
            onlineService.setDoctorCount(0);
            onlineService.setFarmerCount(0);
            onlineService.setFarmCode(farmCode);
            onlineServiceMapper.insert(onlineService);
        }
        return new Result(ResultCode.SUCCESS,onlineService);
    }

    @Override
    public Result getOnlineService(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)){
            farmCode = TokenSign.getFarmCode(request);
        }
        OnlineService onlineService = onlineServiceMapper.getOnlineService(farmCode);
        if (ObjectUtil.isEmpty(onlineService)){
            onlineService = new OnlineService();
            onlineService.setTreatCount(0);
            onlineService.setDoctorCount(0);
            onlineService.setFarmerCount(0);
            onlineService.setFarmCode(farmCode);
            onlineServiceMapper.insert(onlineService);
        }
        return new Result(ResultCode.SUCCESS,onlineService);
    }

    @Override
    public Result saveOnlineService(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)){
            farmCode = TokenSign.getFarmCode(request);
        }
        String treatCount = paramsMap.get("treatCount");
        String farmerCount = paramsMap.get("farmerCount");
        String doctorCount = paramsMap.get("doctorCount");
        OnlineService onlineService1 = new OnlineService();
        onlineService1.setTreatCount(Integer.valueOf(treatCount));
        onlineService1.setFarmerCount(Integer.valueOf(farmerCount));
        onlineService1.setDoctorCount(Integer.valueOf(doctorCount));
        onlineService1.setFarmCode(farmCode);

        OnlineService onlineService = onlineServiceMapper.getOnlineService(farmCode);
        if (ObjectUtil.isEmpty(onlineService)){
            onlineServiceMapper.insert(onlineService1);
        }else {
            onlineService.setTreatCount(Integer.valueOf(treatCount));
            onlineService.setFarmerCount(Integer.valueOf(farmerCount));
            onlineService.setDoctorCount(Integer.valueOf(doctorCount));
            onlineService.setFarmCode(farmCode);
            onlineServiceMapper.updateById(onlineService);
        }
        return new Result(ResultCode.SUCCESS);
    }
}
