package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.OutStock;
import com.huimv.cattle.mapper.OutStockMapper;
import com.huimv.cattle.service.OutStockService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.cattle.utils.DateUtil;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDate;
import java.time.Month;
import java.time.ZonedDateTime;
import java.util.*;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class OutStockServiceImpl extends ServiceImpl<OutStockMapper, OutStock> implements OutStockService {

    @Autowired
    private OutStockMapper outStockMapper;

    @Override
    public Result listOutStock(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        String month = paramsMap.get("months");
        if (month == null || month == "") {
            QueryWrapper<OutStock> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_code", farmCode);
            List<OutStock> list = outStockMapper.selectList(queryWrapper.orderByDesc("year").orderByDesc("month"));
            return new Result(ResultCode.SUCCESS, list);
        } else {
            Integer months = Integer.parseInt(month);
            ZonedDateTime zonedDateTime = ZonedDateTime.now();
            List<OutStock> list = new ArrayList<>();
            for (int i = 0; i < months; i++) {
                if ((zonedDateTime.getMonth().getValue() - i) > 0) {
                    QueryWrapper<OutStock> queryWrapper = new QueryWrapper<>();
                    queryWrapper.eq("farm_code", farmCode);
                    queryWrapper.eq("month", zonedDateTime.getMonth().getValue() - i)
                            .and(Wrapper -> Wrapper.eq("year", zonedDateTime.getYear()));
                    OutStock outStock = outStockMapper.selectOne(queryWrapper);
                    list.add(outStock);
                } else {
                    QueryWrapper<OutStock> queryWrapper = new QueryWrapper<>();
                    queryWrapper.eq("farm_code", farmCode);
                    queryWrapper.eq("month", 12 + zonedDateTime.getMonth().getValue() - i)
                            .and(Wrapper -> Wrapper.eq("year", zonedDateTime.getYear() - 1));
                    OutStock outStock = outStockMapper.selectOne(queryWrapper);
                    list.add(outStock);
                }

            }
            return new Result(ResultCode.SUCCESS, list);
        }

    }

    @Override
    public Result addOutStock(HttpServletRequest httpServletRequest,Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        String list = paramsMap.get("list");
        JSONArray jsonArray = JSONArray.parseArray(list);
        List<OutStock> outStocks = jsonArray.toJavaList(OutStock.class);
        QueryWrapper<OutStock> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.eq("farm_code", farmCode);
        outStockMapper.delete(queryWrapper1);
        for (int i = 0; i < outStocks.size(); i++) {
            Integer month =  outStocks.get(i).getMonth();
            Integer year = outStocks.get(i).getYear();
            QueryWrapper<OutStock> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_code", farmCode);
            queryWrapper.eq("month", month).and(Wrapper -> Wrapper.eq("year", year));
            OutStock outStock = outStockMapper.selectOne(queryWrapper);
            if (ObjectUtil.isEmpty(outStock)) {
                OutStock outStock1 = new OutStock();
                outStock1.setMonth(outStocks.get(i).getMonth());
                outStock1.setYear(outStocks.get(i).getYear());
                outStock1.setMonthName(outStocks.get(i).getMonthName());
                outStock1.setMonth(outStocks.get(i).getMonth());
                outStock1.setOutStock(outStocks.get(i).getOutStock());
                outStock1.setFarmCode(farmCode);
                outStockMapper.insert(outStock1);
            } else {
                outStock.setMonth(outStocks.get(i).getMonth());
                outStock.setYear(outStocks.get(i).getYear());
                outStock.setMonthName(outStocks.get(i).getMonthName());
                outStock.setMonth(outStocks.get(i).getMonth());
                outStock.setOutStock(outStocks.get(i).getOutStock());
                outStock.setFarmCode(farmCode);
                outStockMapper.updateById(outStock);
            }
        }
        return new Result(ResultCode.SUCCESS,"保存成功");
    }
}
