package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.Overview;
import com.huimv.cattle.mapper.OverviewMapper;
import com.huimv.cattle.pojo.Stock;
import com.huimv.cattle.service.OverviewService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.cattle.utils.FarmCodeUtils;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class OverviewServiceImpl extends ServiceImpl<OverviewMapper, Overview> implements OverviewService {

    @Autowired
    private OverviewMapper overviewMapper;
    @Override
    public Result overList(HttpServletRequest httpServletRequest,Map<String, String> paramsMap) {
        String farmCode = FarmCodeUtils.getFarmCode(paramsMap.get("farmCode"), httpServletRequest);
        List<Overview> overviews = overviewMapper.selectList(new QueryWrapper<Overview>().eq("farm_code",farmCode));
        int stockCount=0;
        int outCount=0;
        int breedCount=0;
        int farmCount=0;
        int outputValue=0;
        JSONObject jsonObject = new JSONObject();
        if (overviews.size()==0) {
            jsonObject.put("stockCount", 0);
            jsonObject.put("outCount", 0);
            jsonObject.put("breedCount", 0);
            jsonObject.put("farmCount", 0);
            jsonObject.put("outputValue", 0);
            jsonObject.put("variety", 0);
        } else {
            for (int i = 0; i < overviews.size(); i++) {
                stockCount = stockCount + overviews.get(i).getStockCount();
                outCount = outCount + overviews.get(i).getOutCount();
                breedCount = breedCount + overviews.get(i).getBreedCount();
                farmCount = farmCount + overviews.get(i).getFarmCount();
                outputValue=outputValue+overviews.get(i).getOutputValue().intValue();
            }
            jsonObject.put("stockCount", stockCount);
            jsonObject.put("outCount", outCount);
            jsonObject.put("breedCount", breedCount);
            jsonObject.put("farmCount",farmCount);
            jsonObject.put("outputValue", outputValue);
            jsonObject.put("variety",overviews.get(0).getVariety());
        }
        return new Result(ResultCode.SUCCESS,jsonObject);
    }

    @Override
    public Result add(HttpServletRequest httpServletRequest,Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        QueryWrapper<Overview> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_code", farmCode);
        Overview overList = overviewMapper.selectOne(queryWrapper);
       // Overview overList = overviewMapper.getOverList();
        if (ObjectUtil.isEmpty(overList)) {
            Overview overview = new Overview();
            overview.setStockCount(Integer.parseInt(paramsMap.get("stockCount")));
            overview.setOutCount(Integer.parseInt(paramsMap.get("outCount")));
            overview.setBreedCount(Integer.parseInt(paramsMap.get("breedCount")));
            overview.setFarmCount(Integer.parseInt(paramsMap.get("farmCount")));
            BigDecimal bg = new BigDecimal(paramsMap.get("outputValue"));
            overview.setOutputValue(bg);
            overview.setVariety(paramsMap.get("variety"));
            overview.setFarmCode(farmCode);
            overviewMapper.insert(overview);
            return new Result(ResultCode.SUCCESS,"添加成功");
        } else {
            overList.setStockCount(Integer.parseInt(paramsMap.get("stockCount")));
            overList.setOutCount(Integer.parseInt(paramsMap.get("outCount")));
            overList.setBreedCount(Integer.parseInt(paramsMap.get("breedCount")));
            overList.setFarmCount(Integer.parseInt(paramsMap.get("farmCount")));
            BigDecimal bg = new BigDecimal(paramsMap.get("outputValue"));
            overList.setOutputValue(bg);
            overList.setVariety(paramsMap.get("variety"));
            overviewMapper.updateById(overList);
            return new Result(ResultCode.SUCCESS,"修改成功");
        }
    }

    @Override
    public Result getListOverview(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        QueryWrapper<Overview> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_code", farmCode);
        Overview overview = overviewMapper.selectOne(queryWrapper);
        JSONObject jsonObject = new JSONObject();
        if (ObjectUtil.isEmpty(overview)) {
            jsonObject.put("stockCount", 0);
            jsonObject.put("outCount", 0);
            jsonObject.put("breedCount", 0);
            jsonObject.put("farmCount", 0);
            jsonObject.put("outputValue", 0);
            jsonObject.put("variety", 0);
        } else {
            jsonObject.put("stockCount", overview.getStockCount());
            jsonObject.put("outCount", overview.getOutCount());
            jsonObject.put("breedCount", overview.getBreedCount());
            jsonObject.put("farmCount", overview.getFarmCount());
            jsonObject.put("outputValue", overview.getOutputValue());
            jsonObject.put("variety", overview.getVariety());
        }
        return new Result(ResultCode.SUCCESS,jsonObject);
    }

    @Override
    public Result getListOverviewScreen(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        Overview overview = new Overview();
        if (farmCode == null || farmCode.equals("0")){
            overview = overviewMapper.getListOverview();
        }else {
            QueryWrapper<Overview> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_code", farmCode);
            overview = overviewMapper.selectOne(queryWrapper);
        }
        JSONObject jsonObject = new JSONObject();
        if (ObjectUtil.isEmpty(overview)) {
            jsonObject.put("stockCount", 0);
            jsonObject.put("outCount", 0);
            jsonObject.put("breedCount", 0);
            jsonObject.put("farmCount", 0);
            jsonObject.put("outputValue", 0);
            jsonObject.put("variety", 0);
        } else {
            jsonObject.put("stockCount", overview.getStockCount());
            jsonObject.put("outCount", overview.getOutCount());
            jsonObject.put("breedCount", overview.getBreedCount());
            jsonObject.put("farmCount", overview.getFarmCount());
            jsonObject.put("outputValue", overview.getOutputValue());
            jsonObject.put("variety", overview.getVariety());
        }
        return new Result(ResultCode.SUCCESS,jsonObject);
    }

    @Override
    public Integer getOutStock(JSONObject townJo) {
        QueryWrapper<Overview> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_code", townJo.getString("farmCode"));
        Overview overview = overviewMapper.selectOne(queryWrapper);
        if (ObjectUtil.isEmpty(overview)) {
            return 0;
        } else {
            return overview.getOutCount();
        }
    }
}
