package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.ProductionCapacity;
import com.huimv.cattle.mapper.ProductionCapacityMapper;
import com.huimv.cattle.pojo.SubsidyCount;
import com.huimv.cattle.service.ProductionCapacityService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.cattle.utils.DateUtil;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class ProductionCapacityServiceImpl extends ServiceImpl<ProductionCapacityMapper, ProductionCapacity> implements ProductionCapacityService {
    @Autowired
    private ProductionCapacityMapper productionCapacityMapper;

    @Autowired
    private DateUtil dateUtil;

    @Override
    public Result getProductionCapacity(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)) {
            farmCode = TokenSign.getFarmCode(request);
        }
        String yearNum = paramsMap.get("yearNum");
//        if (StringUtils.isBlank(yearNum)){
//            yearNum = "0";
//        }
        QueryWrapper<ProductionCapacity> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotBlank(yearNum)) {
            queryWrapper.between("year", Integer.valueOf(dateUtil.getThisYear()) - Integer.valueOf(yearNum), Integer.valueOf(dateUtil.getThisYear()));
            //        queryWrapper.last("LIMIT "+yearNum);
        }
        queryWrapper.eq("farm_code", farmCode);
        queryWrapper.orderByDesc("year");
        List<ProductionCapacity> productionCapacities = productionCapacityMapper.selectList(queryWrapper);
        if (ObjectUtil.isEmpty(productionCapacities)) {
            ProductionCapacity productionCapacity1 = new ProductionCapacity();
            productionCapacity1.setYear(Integer.valueOf(dateUtil.getThisYear()));
            productionCapacity1.setFarmCode(farmCode);
            productionCapacities.add(productionCapacity1);
            productionCapacityMapper.insert(productionCapacity1);
        }
        return new Result(ResultCode.SUCCESS, productionCapacities);
    }

    @Override
    public Result saveProductionCapacity(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)) {
            farmCode = TokenSign.getFarmCode(request);
        }
        String list = paramsMap.get("list");
        JSONArray listJa = JSONArray.parseArray(list);
        List<ProductionCapacity> productionCapacityList = listJa.toJavaList(ProductionCapacity.class);
        if (checkRepeat(productionCapacityList)) {
            return new Result(10001, "有重复年份", false);
        } else {
            productionCapacityMapper.deleteAll(farmCode);
        }
        for (int a = listJa.size() - 1; a >= 0; a--) {
            JSONObject jsonObject = listJa.getJSONObject(a);
            Integer year = jsonObject.getInteger("year");
            ProductionCapacity productionCapacity = new ProductionCapacity();
            productionCapacity.setYear(year);
            productionCapacity.setProductionCount(jsonObject.getInteger("productionCount"));
            productionCapacity.setFarmCode(farmCode);
            productionCapacityMapper.insert(productionCapacity);
        }
        return new Result(ResultCode.SUCCESS);
    }

    private Boolean checkRepeat(List<ProductionCapacity> list) {
        List<Integer> collectionOptionList = new ArrayList<>();
        for (ProductionCapacity a : list) {
            collectionOptionList.add(a.getYear());
        }
        Set<Integer> set = new HashSet<>(collectionOptionList);
        return collectionOptionList.size() != set.size();
    }
}
