package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.SalesCount;
import com.huimv.cattle.mapper.SalesCountMapper;
import com.huimv.cattle.service.SalesCountService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class SalesCountServiceImpl extends ServiceImpl<SalesCountMapper, SalesCount> implements SalesCountService {
    @Autowired
    private SalesCountMapper salesCountMapper;
    @Override
    public Result getCount(HttpServletRequest httpServletRequest,Map<String,String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        //List<SalesCount> salesCount = salesCountMapper.getCount();
        QueryWrapper<SalesCount> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_code", farmCode).orderByDesc("year").orderByDesc("quarter");
        List<SalesCount> salesCounts = salesCountMapper.selectList(queryWrapper);
        if (salesCounts.size() == 0) {
            return new Result(ResultCode.SUCCESS,salesCounts);
        } else {
            return new Result(ResultCode.SUCCESS, salesCounts);
        }
    }

    @Override
    public Result addSalesCount(HttpServletRequest httpServletRequest,Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        String list = paramsMap.get("list");
        JSONArray jsonArray = JSONArray.parseArray(list);
        List<SalesCount> lists = jsonArray.toJavaList(SalesCount.class);
        QueryWrapper<SalesCount> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.eq("farm_code", farmCode);
        salesCountMapper.delete(queryWrapper1);
        for (int i = 0; i < lists.size(); i++) {
            Integer year = lists.get(i).getYear();
            Integer quarter = lists.get(i).getQuarter();

            QueryWrapper<SalesCount> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_code", farmCode);
            queryWrapper.eq("year", year).and(Wrapper -> Wrapper.eq("quarter", quarter));
            SalesCount salesCount = salesCountMapper.selectOne(queryWrapper);
            if (ObjectUtil.isEmpty(salesCount)) {
                SalesCount salesCount1 = new SalesCount();
                salesCount1.setQuarterName(lists.get(i).getQuarterName());
                salesCount1.setYear(year);
                salesCount1.setQuarter(quarter);
                salesCount1.setSalesMoney(lists.get(i).getSalesMoney());
                salesCount1.setFarmCode(farmCode);
                salesCountMapper.insert(salesCount1);
            } else {
                salesCount.setFarmCode(farmCode);
                salesCount.setSalesMoney(lists.get(i).getSalesMoney());
                salesCount.setQuarter(quarter);
                salesCount.setYear(year);
                salesCount.setQuarterName(lists.get(i).getQuarterName());
                salesCountMapper.updateById(salesCount);
            }
        }
        return new Result(ResultCode.SUCCESS, "保存成功");
    }
}
