package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.mapper.StockMapper;
import com.huimv.cattle.mapper.SysRegionCounTownVillMapper;
import com.huimv.cattle.pojo.DataSource;
import com.huimv.cattle.pojo.StockStatus;
import com.huimv.cattle.mapper.StockStatusMapper;
import com.huimv.cattle.service.DataSourceService;
import com.huimv.cattle.service.StockStatusService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-14
 */
@Service
public class StockStatusServiceImpl extends ServiceImpl<StockStatusMapper, StockStatus> implements StockStatusService {

    @Autowired
    private StockStatusMapper stockStatusMapper;
    @Resource
    private DataSourceService dataSourceService;
    @Autowired
    private SysRegionCounTownVillMapper sysRegionCounTownVillMapper;

    @Override
    public Result getStockStatus(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)){
            farmCode = TokenSign.getFarmCode(request);
        }
        StockStatus stockStatus = stockStatusMapper.getStockStatus(farmCode);
        if (ObjectUtil.isEmpty(stockStatus)){
            stockStatus = new StockStatus();
            stockStatus.setBreedStock(0);
            stockStatus.setCalfStock(0);
            stockStatus.setRaiseStock(0);
            stockStatus.setFarmCode(farmCode);
            stockStatusMapper.insert(stockStatus);
        }
        return new Result(ResultCode.SUCCESS,stockStatus);
    }

    @Override
    public Result saveStockStatus(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)){
            farmCode = TokenSign.getFarmCode(request);
        }
        String breedStock = paramsMap.get("breedStock");
        String raiseStock = paramsMap.get("raiseStock");
        String calfStock = paramsMap.get("calfStock");

        StockStatus stockStatus1 = new StockStatus();
        stockStatus1.setBreedStock(Integer.parseInt(breedStock));
        stockStatus1.setRaiseStock(Integer.parseInt(raiseStock));
        stockStatus1.setCalfStock(Integer.parseInt(calfStock));
        stockStatus1.setFarmCode(farmCode);
        StockStatus stockStatus = stockStatusMapper.selectOne(new QueryWrapper<StockStatus>().eq("farm_code", farmCode));
        if (ObjectUtil.isEmpty(stockStatus)){
            stockStatusMapper.insert(stockStatus1);
        }else {
            stockStatus.setBreedStock(Integer.parseInt(breedStock));
            stockStatus.setCalfStock(Integer.parseInt(calfStock));
            stockStatus.setRaiseStock(Integer.parseInt(raiseStock));
            stockStatus.setFarmCode(farmCode);
            stockStatusMapper.updateById(stockStatus);
        }
        return new Result(ResultCode.SUCCESS);
    }

    @Override
    public Result getStockStatusScreen(HttpServletRequest request, Map<String, String> paramsMap) {
        String farmCode = paramsMap.get("farmCode");
        if (StringUtils.isBlank(farmCode)){
            farmCode = TokenSign.getFarmCode(request);
        }
        DataSource dataSource = dataSourceService.getDataSourceStatus();
        StockStatus stockStatus = new StockStatus();
        List<String> subCityList = new ArrayList<>();
        if (dataSource.getDsStatus() == 1 && dataSource.getViewType() ==2) {
            if (farmCode == null || farmCode.equals("0")){
                String cityCode = sysRegionCounTownVillMapper.listSub(farmCode);
                String[] city = cityCode.split(",");
                stockStatus = stockStatusMapper.getStockStatusScreen(city);
            }
        }else if (dataSource.getDsStatus() == 1 && dataSource.getViewType() ==3){
            if (farmCode == null || farmCode.equals("0")){
                String cityCode = sysRegionCounTownVillMapper.listSub(farmCode);
                String[] city = cityCode.split(",");
                for (String s : city) {
                    String subCityCode = sysRegionCounTownVillMapper.listSub(s);
                    String[] strings = subCityCode.split(",");
                    for (String string : strings) {
                        subCityList.add(string);
                    }
                }
                String[] subCity = subCityList.toArray(new String[subCityList.size()]);
                stockStatus = stockStatusMapper.getStockStatusScreen(subCity);
            }
        } else{
            stockStatus = stockStatusMapper.getStockStatus(farmCode);
            if (ObjectUtil.isEmpty(stockStatus)){
                stockStatus = new StockStatus();
                stockStatus.setBreedStock(0);
                stockStatus.setCalfStock(0);
                stockStatus.setRaiseStock(0);
                stockStatus.setFarmCode(farmCode);
                stockStatusMapper.insert(stockStatus);
            }
        }
        return new Result(ResultCode.SUCCESS,stockStatus);
    }
}
