package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
//import com.huimv.breed.common.utils.ResultUtil;
import com.huimv.cattle.mapper.SysFarmMapper;
import com.huimv.cattle.mapper.SysUserAccountMapper;
import com.huimv.cattle.pojo.DataSource;
import com.huimv.cattle.pojo.SysFarm;
import com.huimv.cattle.pojo.SysUserAccount;
import com.huimv.cattle.service.DataSourceService;
import com.huimv.cattle.service.StockService;
import com.huimv.cattle.service.SysFarmService;
import com.huimv.cattle.utils.ResultUtil;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
//import com.huimv.saas.admin.mapper.SysFarmMapper;
//import com.huimv.saas.admin.mapper.SysUserAccountMapper;
//import com.huimv.saas.admin.pojo.SysFarm;
//import com.huimv.saas.admin.pojo.SysUserAccount;
//import com.huimv.saas.admin.service.SysFarmService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-09-26
 */
@Service
public class SysFarmServiceImpl extends ServiceImpl<SysFarmMapper, SysFarm> implements SysFarmService {
    @Resource
    private SysFarmMapper sysFarmMapper;
    @Resource
    private SysUserAccountMapper sysUserAccountMapper;
    @Resource
    private ResultUtil resultUtil;
    @Value("${manager.defaultPassword}")
    private String defaultPassword;
    @Resource
    private DataSourceService dataSourceService;
    @Resource
    private StockService stockService;
    @Resource
    private RestTemplate restTemplate;

    @Override
    public Result initFarmFlow(HttpServletRequest request, Map<String, String> paramsMap) {
        //--step1:创建牧场；
        //--step2:根据默认牧场管理员权限组创建牧场账号；

        return null;
    }

    @Override
    public Result listFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        String pageNo = paramsMap.get("pageNo") + "";
        if (pageNo == null) {
            pageNo = "1";
        }
        String pageSize = paramsMap.get("pageSize") + "";
        if (pageSize == null) {
            pageSize = "10";
        }
        //牧场名称
        String farmName = paramsMap.get("farmName");
        QueryWrapper<SysFarm> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(StringUtils.isNotBlank(farmName), "farm_name", farmName);
        queryWrapper.orderByAsc("id");
        Page<SysFarm> page = new Page<>(Integer.parseInt(pageNo), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, sysFarmMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result newFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        //
        String farmStatus = paramsMap.get("farmStatus");
        if (StringUtils.isBlank(farmStatus)) {
            farmStatus = "1";
        }
        String farmCode = paramsMap.get("farmCode");
        List<SysFarm> farms = sysFarmMapper.selectList(new QueryWrapper<SysFarm>().eq("farm_code", farmCode));
        System.out.println(farms.toString());
        if (ObjectUtil.isNotEmpty(farms)) {
            return new Result(10010, "牧场编号已存在", false);
        }


        SysFarm sysFarm = new SysFarm();
        sysFarm.setFarmName(paramsMap.get("farmName"));
        sysFarm.setFarmCode(paramsMap.get("farmCode"));
        sysFarm.setLinkman(paramsMap.get("linkman"));
        sysFarm.setPhone(paramsMap.get("phone"));
        sysFarm.setAddress(paramsMap.get("address"));
        sysFarm.setFarmStatus(Integer.parseInt(farmStatus));
        sysFarm.setRemark(paramsMap.get("remark"));
        sysFarm.setAdcode(paramsMap.get("adCode"));
        return resultUtil.getResult(sysFarmMapper.insert(sysFarm));
    }

    @Override
    public Result editFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        //
        String farmStatus = paramsMap.get("farmStatus");
        if (StringUtils.isBlank(farmStatus)) {
            farmStatus = "1";
        }
        SysFarm sysFarm = new SysFarm();
        sysFarm.setId(Integer.parseInt(paramsMap.get("id")));
        sysFarm.setFarmName(paramsMap.get("farmName"));
        sysFarm.setFarmCode(paramsMap.get("farmCode"));
        sysFarm.setLinkman(paramsMap.get("linkman"));
        sysFarm.setPhone(paramsMap.get("phone"));
        sysFarm.setAddress(paramsMap.get("address"));
        sysFarm.setFarmStatus(Integer.parseInt(farmStatus));
        sysFarm.setRemark(paramsMap.get("remark"));
        sysFarm.setAdcode(paramsMap.get("adCode"));
        return resultUtil.getResult(sysFarmMapper.updateById(sysFarm));
    }

    @Override
    public Result removeFarm(HttpServletRequest request, Map<String, String> paramsMap) {
        String ids = paramsMap.get("ids");
        String[] idArray = ids.split(",");
        List<String> idList = Arrays.asList(idArray);
        return resultUtil.getResult(sysFarmMapper.deleteBatchIds(idList));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result resetPassword(HttpServletRequest request, Map<String, String> paramsMap) {
        String ids = paramsMap.get("farmCodes");
        String[] idArray = ids.split(",");
        int rows = 0;
        for (String id : idArray) {
            SysUserAccount SysUserAccount = new SysUserAccount();
            SysUserAccount.setFarmCode(id);
            SysUserAccount.setPassword(defaultPassword);
            rows += sysUserAccountMapper.updateById(SysUserAccount);
        }
        return resultUtil.getResult(rows);
    }

    @Override
    public Result getAllFarmId(HttpServletRequest request, Map<String, String> paramsMap) {
        QueryWrapper<SysFarm> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("id");
        List<SysFarm> sysFarmList = sysFarmMapper.selectList(queryWrapper);
        StringBuilder idSb = new StringBuilder();
        for (SysFarm farmData : sysFarmList) {
            if (idSb.length() > 0) {
                idSb.append(",");
            }
            idSb.append(farmData.getFarmCode());
        }
        if (idSb.length() > 0) {
            return new Result(ResultCode.SUCCESS, idSb.toString());
        } else {
            return new Result(ResultCode.FAIL);
        }
    }

    @Override
    public Result listAllTownsCount(HttpServletRequest request) {
        /////////////////////////////////////////////////////////////////////////
        //读取所有乡镇
        //统计所有存栏（手填报或者从养殖云获取）
        /////////////////////////////////////////////////////////////////////////

        //读取所有乡镇
        JSONArray allTownsJa = getAllTowns();
        System.out.println("allTownsJa=" + allTownsJa);
        if (allTownsJa.size() == 0) {
            return new Result(0, "当前未查询到任何乡镇数据.", false);
        }
        //读取模式切换
        DataSource dataSource = dataSourceService.getDataSourceStatus();
        //view=2,显示镇汇总数据
        if (dataSource.getDsStatus() == 1) {
            //status=1,显示镇（手填）数据
            return stockService.getAllTownStock(request, allTownsJa);
        } else {
            //status=2,显示镇汇总（养殖云）数据
            return getStockFromBreedCloud(allTownsJa);
        }
    }

    //获取所有乡镇信息
    private JSONArray getAllTowns() {
        QueryWrapper<SysFarm> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByAsc("id");
        List<SysFarm> sysFarmList = sysFarmMapper.selectList(queryWrapper);
        JSONArray townsJa = new JSONArray();
        for (SysFarm farmData : sysFarmList) {
            JSONObject townJo = new JSONObject();
            townsJa.add(townJo);
            townJo.put("farmName", farmData.getFarmName());
            townJo.put("farmCode", farmData.getFarmCode());
            townJo.put("adCode", farmData.getAdcode());
            townJo.put("townCode", farmData.getAdcode().substring(farmData.getAdcode().lastIndexOf(",") + 1, farmData.getAdcode().length()));
        }
        return townsJa;
    }

    //显示镇汇总（养殖云）数据
    private Result getStockFromBreedCloud(JSONArray allTownsJa) {
        HttpHeaders httpHeaders = new HttpHeaders();
        MediaType type = MediaType.parseMediaType("application/json;charset=UTF-8");
        httpHeaders.setContentType(type);
        HashMap<String, Object> map = new HashMap<>();
        //这里提交的是区县编码或乡镇编码
        map.put("allTown", allTownsJa.toJSONString());
        HttpEntity<Map<String, Object>> objectHttpEntity = new HttpEntity<>(map, httpHeaders);
        //读取真实数据
        String remoteUrl = "http://123.60.134.84:10001/breed/api/v1.0.0/cattle/getStockByDivision2";
        ResponseEntity<String> entity = restTemplate.postForEntity(remoteUrl, objectHttpEntity, String.class);
        if (entity.getStatusCode().toString().contains("200")) {
            String body = entity.getBody();
//            System.out.println(body);
            JSONObject resultJo = JSON.parseObject(body);
//            System.out.println("resultJo=" + resultJo);
            return new Result(ResultCode.SUCCESS, resultJo.getJSONArray("data"));
        } else {
            return new Result(ResultCode.FAIL, "调取远程数据出错.");
        }
    }
}
