package com.huimv.cattle.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
//import com.huimv.breed.common.utils.ConstUtil;
//import com.huimv.breed.common.utils.DateUtil;
//import com.huimv.breed.common.utils.ResultUtil;
import com.huimv.cattle.utils.ConstUtil;
import com.huimv.cattle.utils.DateUtil;
import com.huimv.cattle.utils.ResultUtil;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import com.huimv.cattle.mapper.SysFarmMapper;
import com.huimv.cattle.mapper.SysFarmServiceMapper;
import com.huimv.cattle.pojo.SysFarm;
import com.huimv.cattle.pojo.SysFarmService;
import com.huimv.cattle.service.SysFarmServiceService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-09-26
 */
@Service
public class SysFarmServiceServiceImpl extends ServiceImpl<SysFarmServiceMapper, SysFarmService> implements SysFarmServiceService {
    @Resource
    private SysFarmServiceMapper sysFarmServiceMapper;
    @Resource
    private SysFarmMapper sysFarmMapper;
    @Resource
    private ResultUtil resultUtil;

    @Override
    public Result listAllService(HttpServletRequest request, Map<String, String> paramsMap) {
        String pageNo = paramsMap.get("pageNo") + "";
        if (pageNo == null) {
            pageNo = "1";
        }
        String pageSize = paramsMap.get("pageSize") + "";
        if (pageSize == null) {
            pageSize = "10";
        }
        //牧场名称
        String farmName = paramsMap.get("farmName");
        QueryWrapper<SysFarmService> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(StringUtils.isNotBlank(farmName), "farm_name", farmName);
        queryWrapper.orderByDesc("id");
        Page<SysFarmService> page = new Page<>(Integer.parseInt(pageNo), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, sysFarmServiceMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result listMyService(HttpServletRequest request, Map<String, String> paramsMap) {
        String pageNo = paramsMap.get("pageNo") + "";
        if (pageNo == null) {
            pageNo = "1";
        }
        String pageSize = paramsMap.get("pageSize") + "";
        if (pageSize == null) {
            pageSize = "10";
        }
        //牧场名称
        String farmCode = paramsMap.get("farmCode");
        QueryWrapper<SysFarmService> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtils.isNotBlank(farmCode), "farm_code", farmCode);
        Page<SysFarmService> page = new Page<>(Integer.parseInt(pageNo), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, sysFarmServiceMapper.selectPage(page, queryWrapper));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result newService(HttpServletRequest request, Map<String, String> paramsMap) throws ParseException {
        //--Logic Rule:
        //--服务周期期间不能重叠;
        //--当前只能有一个有效期（添加最新有效期的时候，将其余的都是为无效）
        //--添加之前先判断新的有效期是否合格。
        //--End
//        String farmCode = request.getHeader("farmCode");
        String farmCode =    paramsMap.get("farmCode");
        DateUtil dateUtil = new DateUtil();
        Date currentStartDate = dateUtil.parseDate(paramsMap.get("startDate"));
        int serviceCycle = Integer.parseInt(paramsMap.get("serviceCycle"));
        int serviceStatus = Integer.parseInt(paramsMap.get("serviceStatus"));

        //Step1:读取当前周期，先判断日期是否合理
        QueryWrapper<SysFarmService> queryWrapperFarmService = new QueryWrapper<>();
        queryWrapperFarmService.eq("farm_code", farmCode);
//        queryWrapperFarmService.eq("current_service", "1");
        queryWrapperFarmService.orderByDesc("id");
        List<SysFarmService> sysFarmServiceList = sysFarmServiceMapper.selectList(queryWrapperFarmService);
        if (sysFarmServiceList.size() == 0) {
            //Step2:不存在服务周期，直接插入最新的服务周期记录
            saveNewServiceCycle(farmCode, currentStartDate, serviceCycle, serviceStatus);
            return resultUtil.getResult(1);
        } else {
            //判断当前开始的服务周期是否晚于当前系统中最后一条的结束日期
            SysFarmService lastSysFarmService = sysFarmServiceList.get(0);
            Date lastEndDate = lastSysFarmService.getEndDate();
            if (currentStartDate.after(lastEndDate)) {
                //Step2:插入最新的服务周期记录
                saveNewServiceCycle(farmCode, currentStartDate, serviceCycle, serviceStatus);

                //Step3:将已经存在记录的周期状态设置为0（非当前周期）
                lastSysFarmService.setCurrentStatus(0);
                sysFarmServiceMapper.updateById(lastSysFarmService);
                return resultUtil.getResult(1);
            } else {
                return new Result(ConstUtil.ERR_SERVICE_SAME_CODE, ConstUtil.ERR_SERVICE_SAME_INFO, false);
            }
        }
    }

    //保存新的服务周期
    private void saveNewServiceCycle(String farmCode, Date currentStartDate, Integer serviceCycle, Integer serviceStatus) {
        SysFarm sysFarm = sysFarmMapper.selectOne(new QueryWrapper<SysFarm>().eq("farm_code", farmCode));
        SysFarmService sysFarmService = new SysFarmService();
        sysFarmService.setFarmName(sysFarm.getFarmName());
        sysFarmService.setFarmCode(farmCode);
        sysFarmService.setStartDate(currentStartDate);
        sysFarmService.setEndDate(cn.hutool.core.date.DateUtil.offsetMonth(currentStartDate, serviceCycle));
        sysFarmService.setServiceCycle(serviceCycle);
//        sysFarmService.setServiceDays(Integer.parseInt(paramsMap.get("serviceDays")));
        sysFarmService.setServiceStatus(serviceStatus);
        sysFarmService.setCurrentStatus(1);
        sysFarmServiceMapper.insert(sysFarmService);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result removeService(HttpServletRequest request, Map<String, String> paramsMap) {
        String ids = paramsMap.get("ids");
        String[] idArray = ids.split(",");
        List<String> idList = Arrays.asList(idArray);
        sysFarmServiceMapper.deleteBatchIds(idList);
        //将最后一条记录的“是否当前周期”设置为1（当前服务周期）
        String farmCode = request.getHeader("farmCode");
        QueryWrapper<SysFarmService> queryWrapperFarmService = new QueryWrapper<>();
        queryWrapperFarmService.eq("farm_code", farmCode);
        queryWrapperFarmService.orderByDesc("id");
        List<SysFarmService> sysFarmServiceList = sysFarmServiceMapper.selectList(queryWrapperFarmService);
        if (sysFarmServiceList.size() > 0) {
            SysFarmService lastSysFarmService = sysFarmServiceList.get(0);
            lastSysFarmService.setCurrentStatus(1);
            sysFarmServiceMapper.updateById(lastSysFarmService);
        }
        return resultUtil.getResult(1);
    }

    @Override
    public Result timeoutService(HttpServletRequest request, Map<String, String> paramsMap) {
        String id = paramsMap.get("id");
        String serviceStatus = paramsMap.get("serviceStatus");
        SysFarmService sysFarmService = new SysFarmService();
        sysFarmService.setId(Integer.parseInt(id));
        sysFarmService.setServiceStatus(Integer.parseInt(serviceStatus));
        return resultUtil.getResult(sysFarmServiceMapper.updateById(sysFarmService));
    }

    @Override
    public Result cancelService(HttpServletRequest request, Map<String, String> paramsMap) {
        String id = paramsMap.get("id");
        String serviceStatus = paramsMap.get("serviceStatus");
        SysFarmService sysFarmService = new SysFarmService();
        sysFarmService.setId(Integer.parseInt(id));
        sysFarmService.setServiceStatus(Integer.parseInt(serviceStatus));
        return resultUtil.getResult(sysFarmServiceMapper.updateById(sysFarmService));
    }
}
