package com.huimv.cattle.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.mapper.SysGroupMenuMapper;
import com.huimv.cattle.pojo.SysGroupMenu;
import com.huimv.cattle.service.SysGroupMenuService;
import com.huimv.cattle.utils.ConstUtil;
import com.huimv.cattle.utils.ResultUtil;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-09-26
 */
@Service
public class SysGroupMenuServiceImpl extends ServiceImpl<SysGroupMenuMapper, SysGroupMenu> implements SysGroupMenuService {
    @Resource
    private SysGroupMenuMapper sysGroupMenuMapper;

    @Resource
    private ResultUtil resultUtil;

    // 事务处理
     @Override
    @Transactional(rollbackFor = Exception.class)
    public Result saveGroupMenu(Map<String, String> paramsMap) {

         String groupId = paramsMap.get("groupId");
         String isAll = paramsMap.get("isAll");
         String menuIds = paramsMap.get("menuIds");
         QueryWrapper<SysGroupMenu> queryWrapper = new QueryWrapper<>();
         queryWrapper.eq(StringUtils.isNotBlank(groupId),"group_id",groupId);
         sysGroupMenuMapper.delete(queryWrapper);
         if (com.baomidou.mybatisplus.core.toolkit.StringUtils.isNotBlank(menuIds)) {
             String[] menuIdsArray = menuIds.split(",");
             String[] split = isAll.split(",");
             boolean isAlla = StringUtils.isNotBlank(isAll);
             for (int a = 0; a < menuIdsArray.length; a++) {
                 SysGroupMenu groupMenu = new SysGroupMenu();
                 groupMenu.setGroupId(Integer.parseInt(groupId));
                 groupMenu.setMenuId(Integer.parseInt(menuIdsArray[a]));
                 if (isAlla){
                     for (String s : split) {
                         if (groupMenu.getMenuId() == Integer.parseInt(s)) {
                             groupMenu.setIsAll(1);
                         }
                     }
                 }
                 sysGroupMenuMapper.insert(groupMenu);
             }
         }


         return resultUtil.getResult(1);

     }
    /*@Override
    @Transactional(rollbackFor = Exception.class)
    public Result saveGroupMenu(Map<String, String> paramsMap) {
        String groupId = paramsMap.get("groupId");
        String isAll = paramsMap.get("isAll");
        String[] isAllArray = isAll.split(",");
        String menuIds = paramsMap.get("menuIds");
        String[] menuArray = menuIds.split(",");
        // 过滤上级菜单id
        List<String> menuList = new ArrayList();
        for(int a=0;a<menuArray.length;a++){
            boolean isExist = false;
            for(int b=0;b<isAllArray.length;b++){
                if(menuArray[a].trim().equalsIgnoreCase(isAllArray[b])){
                    isExist = true;
                    break;
                }
            }
            if(!isExist){
                menuList.add(menuArray[a]);
            }
        }
        //-- 删除权限组绑定才菜单 --//
        QueryWrapper<SysGroupMenu> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtils.isNotBlank(groupId),"group_id",groupId);
        sysGroupMenuMapper.delete(queryWrapper);
        //-- 新增权限组绑定菜单 --//
        int rows = 0;
        for(int a=0;a<menuList.size();a++){
            SysGroupMenu newSysGroupMenu = new SysGroupMenu();
            newSysGroupMenu.setGroupId(Integer.parseInt(groupId));
            newSysGroupMenu.setMenuId(Integer.parseInt(menuList.get(a)));
            rows += sysGroupMenuMapper.insert(newSysGroupMenu);
        }
        return resultUtil.getResult(rows);
    }*/

    /**
     * @Method      : getMenuByGroupId
     * @Description : 根据权限组获取菜单
     * @Params      : [paramsMap]
     * @Return      : com.huimv.common.utils.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/10/10       
     * @Time        : 14:07
     */
    @Override
    public Result getMenuByGroupId(Map<String, String> paramsMap) {
        String groupId = paramsMap.get("groupId");
        QueryWrapper<SysGroupMenu> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtils.isNotBlank(groupId),"group_id",groupId);
        queryWrapper.eq("is_all",0);
        List<SysGroupMenu> sysGroupMenuList = sysGroupMenuMapper.selectList(queryWrapper);
        if(sysGroupMenuList.size() == 0){
            return new Result(ConstUtil.ERR_MYMENU_EMPTY_CODE,ConstUtil.ERR_MYMENU_EMPTY_INFO,false);
        }
        StringBuilder menuIdSb = new StringBuilder();
        for(SysGroupMenu groupMenu:sysGroupMenuList){
            menuIdSb.append(groupMenu.getMenuId());
            if(menuIdSb.length()>0){
                menuIdSb.append(",");
            }
        }
        return new Result(ResultCode.SUCCESS,menuIdSb.toString());
    }
}
