package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
//import com.huimv.breed.common.token.TokenSign;
//import com.huimv.breed.common.utils.ConstUtil;
//import com.huimv.breed.common.utils.ResultUtil;
import com.huimv.cattle.mapper.SysMenuMapper;
import com.huimv.cattle.pojo.SysMenu;
import com.huimv.cattle.service.SysMenuService;
import com.huimv.cattle.token.TokenSign;
import com.huimv.cattle.utils.ConstUtil;
import com.huimv.cattle.utils.ResultUtil;
import com.huimv.common.exception.ExceptionEnum;
import com.huimv.common.exception.MiException;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
//import com.huimv.saas.admin.mapper.SysMenuMapper;
//import com.huimv.saas.admin.pojo.SysMenu;
//import com.huimv.saas.admin.service.SysMenuService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-09-26
 */
@Service
public class SysMenuServiceImpl extends ServiceImpl<SysMenuMapper, SysMenu> implements SysMenuService {
    @Resource
    private SysMenuMapper sysMenuMapper;
    @Resource
    private ResultUtil resultUtil;

    @Override
    public Result newMenu(Map<String, String> paramMap) {
        //
        String weight = paramMap.get("weight");
        if(StringUtils.isBlank(weight)){
            weight = "0";
        }
        //parentId
        String parentId = paramMap.get("parentId");
        if(StringUtils.isBlank(parentId)){
            parentId = "0";
        }
        //sort
        String sort = paramMap.get("sort");
        if(StringUtils.isBlank(sort)){
            sort = "0";
        }
        //ifShow
        String ifShow = paramMap.get("ifShow");
        if(StringUtils.isBlank(ifShow)){
            ifShow = "1";
        }
        //menuType
        String menuType = paramMap.get("menuType");
        if(StringUtils.isBlank(menuType)){
            menuType = "1";
        }
        SysMenu newSysMenu = new SysMenu();
        newSysMenu.setTitle(paramMap.get("title"));
        newSysMenu.setUrl(paramMap.get("url"));
        newSysMenu.setWeight(Integer.parseInt(weight));
        newSysMenu.setParentId(Integer.parseInt(parentId));
        newSysMenu.setSort(Integer.parseInt(sort));
        newSysMenu.setPermission(paramMap.get("permission") );
        newSysMenu.setIfShow(Integer.parseInt(ifShow));
        newSysMenu.setMenuType(Integer.parseInt(menuType));
        return resultUtil.getResult(sysMenuMapper.insert(newSysMenu));
    }

    @Override
    public Result editMenu(Map<String, String> paramMap) {
        //
        String weight = paramMap.get("weight");
        if(StringUtils.isBlank(weight)){
            weight = "0";
        }
        //parentId
        String parentId = paramMap.get("parentId");
        if(StringUtils.isBlank(parentId)){
            parentId = "0";
        }
        //sort
        String sort = paramMap.get("sort");
        if(StringUtils.isBlank(sort)){
            sort = "0";
        }
        //ifShow
        String ifShow = paramMap.get("ifShow");
        if(StringUtils.isBlank(ifShow)){
            ifShow = "1";
        }
        //menuType
        String menuType = paramMap.get("menuType");
        if(StringUtils.isBlank(menuType)){
            menuType = "1";
        }
        SysMenu newSysMenu = new SysMenu();
        newSysMenu.setId(Integer.parseInt(paramMap.get("id") + ""));
        newSysMenu.setTitle(paramMap.get("title"));
        newSysMenu.setUrl(paramMap.get("url"));
        newSysMenu.setWeight(Integer.parseInt(weight));
        newSysMenu.setParentId(Integer.parseInt(parentId));
        newSysMenu.setSort(Integer.parseInt(sort));
        newSysMenu.setPermission(paramMap.get("permission") );
        newSysMenu.setIfShow(Integer.parseInt(ifShow));
//        newSysMenu.setMenuType(Integer.parseInt(menuType));
        return resultUtil.getResult(sysMenuMapper.updateById(newSysMenu));
    }

    @Override
    public Result removeMenu(Map<String, String> paramMap) {
        QueryWrapper<SysMenu> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("parent_id", Integer.parseInt(paramMap.get("id") + ""));
        if (sysMenuMapper.selectCount(queryWrapper) > 0) {
            return new Result(ConstUtil.ERR_CHILDMENU_CODE, ConstUtil.ERR_CHILDMENU_INFO, false);
        } else {
            return resultUtil.getResult(sysMenuMapper.deleteById(Integer.parseInt(paramMap.get("id") + "")));
        }
    }

    /**
     * @Method : listMyMenu
     * @Description : 显示我的个人所有菜单
     * @Params : [paramMap]
     * @Return : com.huimv.common.utils.Result
     * @Author : ZhuoNing
     * @Date : 2022/10/10
     * @Time : 9:47
     */
    @Override
    public Result getMyMenu(HttpServletRequest request, Map<String, String> paramMap) {
        //从header中获取参数uid
//        String uid = request.getHeader("uid");
        //从Body中获取参数
//        String userId = paramMap.get("userId");
        String userId = TokenSign.getMemberIdByJwtToken(request)+"";
        List<SysMenu> myMenuList = new ArrayList<SysMenu>();
        if ("1".equals(userId)){
            myMenuList = sysMenuMapper.selectList(new QueryWrapper<SysMenu>().orderByAsc("sort"));
        }else {
            myMenuList = sysMenuMapper.getMyMenu(userId);
        }

//        List<SysMenu> myMenuList = sysMenuMapper.getMyMenu2(userId);
        //--构建菜单树--//
//        JSONArray menuTreeJa = _buildMenuTree(myMenuList);
        List<SysMenu> menuTreeJa = _buildMenuTreeY(myMenuList);
        return new Result(ResultCode.SUCCESS, menuTreeJa);
    }

    @Override
    public List<String>  getMyButton(HttpServletRequest request,Map<String, String> paramMap) {
        Integer userId = TokenSign.getMemberIdByJwtToken(request);
        if ( 1 == userId){
            List<SysMenu> menus = sysMenuMapper.selectList(null);
            List<String> list = new ArrayList<>();
            for (SysMenu menu : menus) {
                list.add(menu.getPermission());
            }
            return list;
        }
        return sysMenuMapper.getMyButton(userId);
    }

    /**
     * @Method      : list
     * @Description : 展示所有菜单
     * @Params      : [paramMap]
     * @Return      : com.huimv.common.utils.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/10/11       
     * @Time        : 15:17
     */
    @Override
    public Result list(Map<String, String> paramMap) {
        String menuType = paramMap.get("menuType");
        QueryWrapper<SysMenu> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtils.isNotBlank(menuType),"menu_type", menuType);
        queryWrapper.orderByAsc("sort");
        List<SysMenu> allMenuList = sysMenuMapper.selectList(queryWrapper);
        //构建菜单树
//        JSONArray menuTreeJa = _buildMenuTree(allMenuList);
        List<SysMenu> menuTreeJa = _buildMenuTreeY(allMenuList);
        return new Result(ResultCode.SUCCESS, menuTreeJa);
    }

    //构建树
    private List<SysMenu> _buildMenuTreeY(List<SysMenu> allMenuList) {

        List<SysMenu> collect = allMenuList.stream().filter(m -> m.getParentId() == 0).map(
                (m) -> {
                    m.setChildren(getChildrenList(m, allMenuList));
                    return m;
                }
        ).collect(Collectors.toList());
        return collect;
    }
    public  List<SysMenu> getChildrenList(SysMenu tree, List<SysMenu> list){
        List<SysMenu> children = list.stream().filter(item -> Objects.equals(item.getParentId(), tree.getId())).map(
                (item) -> {
                    item.setChildren(getChildrenList(item, list));
                    return item;
                }
        ).collect(Collectors.toList());
        return children;
    }


    //构建菜单树
    private JSONArray _buildMenuTree(List<SysMenu> menuList) {
        JSONArray rootMenuJa = new JSONArray();
        List<SysMenu> nonRootNodeList = new ArrayList();
        // 构建顶级菜单节点
        for (SysMenu sysMenu : menuList) {
            if (sysMenu.getParentId() == 0) {
//                JSONObject rootJo = JSON.parseObject(JSON.toJSONString(sysMenu));
                JSONObject rootJo = _createNode(sysMenu);
                rootJo.put("children", new JSONArray());
                rootMenuJa.add(rootJo);
            } else {
                nonRootNodeList.add(sysMenu);
            }
        }
        // 构建非顶级菜单节点
        for (SysMenu newMenu : nonRootNodeList) {
            //新建菜单树节点
            _appendMenuTreeNode(newMenu, rootMenuJa);
        }
        return rootMenuJa;
    }

    //创建新节点
    public JSONObject _createNode(SysMenu sysMenu) {
        JSONObject nodeJo = JSON.parseObject(JSON.toJSONString(sysMenu));
        nodeJo.put("pid", sysMenu.getParentId());
        nodeJo.put("value", sysMenu.getId());
        return nodeJo;
    }

    //构建菜单树节点
    private void _appendMenuTreeNode(SysMenu newMenu, JSONArray rootMenuJa) {
        for (int a = 0; a < rootMenuJa.size(); a++) {
            JSONObject rootJo = rootMenuJa.getJSONObject(a);
            if (newMenu.getParentId().equals(rootJo.getInteger("id"))) {
                JSONArray childrenJa = rootJo.getJSONArray("children");
                if (childrenJa == null) {
                    childrenJa = new JSONArray();
//                    childrenJa.add(JSON.parseObject(JSON.toJSONString(newMenu)));
                    childrenJa.add(_createNode(newMenu));
                    rootJo.put("children", childrenJa);
                } else {
//                    childrenJa.add(JSON.parseObject(JSON.toJSONString(newMenu)));
                    childrenJa.add(_createNode(newMenu));
                }
            } else {
                JSONArray childrenJa = rootJo.getJSONArray("children");
                if (childrenJa != null && childrenJa.size() > 0) {
                    //递归构建菜单树节点
                    _appendMenuTreeNode(newMenu, childrenJa);
                }
            }
        }
    }
}
